@@ -25,7 +25,7 @@ def video_key(video):
     )
 
 def video_valid(video):
-    return (video.url.text.startswith("http") and v.url.text.endswith(".mp4"))
+    return (video.url.text.startswith("http") and video.url.text.endswith(".mp4"))
 
 def get_id(url):
     return int(re.search(r"[^0-9]*([0-9]+)[^0-9]*", url).group(1))
